Module: BookingSync::API::Client::Photos

Included in:
BookingSync::API::Client
Defined in:
lib/bookingsync/api/client/photos.rb

Instance Method Summary collapse

Instance Method Details

#photos(options = {}, &block) ⇒ Array<BookingSync::API::Resource>

List photos

Returns photos for the account user is authenticated with.

Examples:

Get the list of photos for the current account

photos = @api.photos
photos.first.position # => 1

Get the list of photos only with medium_url and position for smaller response

@api.photos(fields: [:medium_url, :position])

Parameters:

  • options (Hash) (defaults to: {}) —

    A customizable set of options.

Options Hash (options):

  • fields: (Array) —

    List of fields to be fetched.

Returns:

See Also:



17
18
19
# File 'lib/bookingsync/api/client/photos.rb', line 17

def photos(options = {}, &block)
  paginate :photos, options, &block
end