Module: BookingSync::API::Client::RentalsFees

Included in:
BookingSync::API::Client
Defined in:
lib/bookingsync/api/client/rentals_fees.rb

Instance Method Summary collapse

Instance Method Details

#rentals_fees(options = {}, &block) ⇒ Array<BookingSync::API::Resource>

List rentals fees

Returns rentals fees for the account user is authenticated with.

Examples:

Get the list of rentals fees for the current account

rentals_fees = @api.rentals fees
rentals_fees.first.always_applied # => true

Get the list of rentals fees only with start_date and end_date for smaller response

@api.rentals fees(fields: [:start_date, :end_date])

Parameters:

  • options (Hash) (defaults to: {}) —

    A customizable set of options.

Options Hash (options):

  • fields: (Array) —

    List of fields to be fetched.

Returns:

See Also:



17
18
19
# File 'lib/bookingsync/api/client/rentals_fees.rb', line 17

def rentals_fees(options = {}, &block)
  paginate :rentals_fees, options, &block
end