Module: BookingSync::API::Client::Taxes

Included in:
BookingSync::API::Client
Defined in:
lib/bookingsync/api/client/taxes.rb

Instance Method Summary collapse

Instance Method Details

#taxes(options = {}, &block) ⇒ Array<BookingSync::API::Resource>

List taxes

Returns taxes for the account user is authenticated with.

Examples:

Get the list of taxes for the current account

taxes = @api.taxes
taxes.first.percentage # => 20.0

Get the list of taxes only with percentage for smaller response

@api.taxes(fields: [:percentage])

Parameters:

  • options (Hash) (defaults to: {}) —

    A customizable set of options.

Options Hash (options):

  • fields: (Array) —

    List of fields to be fetched.

Returns:

See Also:



17
18
19
# File 'lib/bookingsync/api/client/taxes.rb', line 17

def taxes(options = {}, &block)
  paginate :taxes, options, &block
end